-- ---------------------------------------------------------------------
-- COLOR VALUES
-- ---------------------------------------------------------------------
-- Download palettes and files from: http://ethanschoonover.com/solarized
--
-- L\*a\*b values are canonical (White D65, Reference D50), other values are
-- matched in sRGB space.
--
-- SOLARIZED HEX     16/8 TERMCOL  XTERM/HEX   L*A*B      sRGB        HSB
-- --------- ------- ---- -------  ----------- ---------- ----------- -----------
-- base03    #002b36  8/4 brblack  234 #1c1c1c 15 -12 -12   0  43  54 193 100  21
-- base02    #073642  0/4 black    235 #262626 20 -12 -12   7  54  66 192  90  26
-- base01    #586e75 10/7 brgreen  240 #4e4e4e 45 -07 -07  88 110 117 194  25  46
-- base00    #657b83 11/7 bryellow 241 #585858 50 -07 -07 101 123 131 195  23  51
-- base0     #839496 12/6 brblue   244 #808080 60 -06 -03 131 148 150 186  13  59
-- base1     #93a1a1 14/4 brcyan   245 #8a8a8a 65 -05 -02 147 161 161 180   9  63
-- base2     #eee8d5  7/7 white    254 #d7d7af 92 -00  10 238 232 213  44  11  93
-- base3     #fdf6e3 15/7 brwhite  230 #ffffd7 97  00  10 253 246 227  44  10  99
-- yellow    #b58900  3/3 yellow   136 #af8700 60  10  65 181 137   0  45 100  71
-- orange    #cb4b16  9/3 brred    166 #d75f00 50  50  55 203  75  22  18  89  80
-- red       #dc322f  1/1 red      160 #d70000 50  65  45 220  50  47   1  79  86
-- magenta   #d33682  5/5 magenta  125 #af005f 50  65 -05 211  54 130 331  74  83
-- violet    #6c71c4 13/5 brmagenta 61 #5f5faf 50  15 -45 108 113 196 237  45  77
-- blue      #268bd2  4/4 blue      33 #0087ff 55 -10 -45  38 139 210 205  82  82
-- cyan      #2aa198  6/6 cyan      37 #00afaf 60 -35 -05  42 161 152 175  74  63
-- green     #859900  2/2 green     64 #5f8700 60 -20  65 133 153   0  68 100  60
--
-- ---------------------------------------------------------------------
-- COLORSCHEME HACKING
-- ---------------------------------------------------------------------
--
-- Useful commands for testing colorschemes:
-- :source $VIMRUNTIME/syntax/hitest.vim
-- :help highlight-groups
-- :help cterm-colors
-- :help group-name
--
-- Useful links for developing colorschemes:
-- http://www.vim.org/scripts/script.php?script_id=2937
-- http://vimcasts.org/episodes/creating-colorschemes-for-vim/
-- http://www.frexx.de/xterm-256-notes/"

local table = require('table')

function clear_highlight(name)
  vim.api.nvim_set_hl(0, name, {})
end

function highlight(opts)
	assert(opts.name, "The name of the group is missing")

	local histr = "highlight! " .. opts.name .. " "
  local args = { }

	if opts.fg then
		histr = histr .. "ctermfg=" .. opts.fg[1] .. " "
		histr = histr .. "guifg=" .. opts.fg[2] .. " "

    args.ctermfg = opts.fg[1]
    args.fg = opts.fg[2]
	end

	if opts.bg then
		histr = histr .. "ctermbg=" .. opts.bg[1] .. " "
		histr = histr .. "guibg=" .. opts.bg[2] .. " "

    args.ctermbg = opts.bg[1]
    args.bg = opts.bg[2]
	end

	if opts.sp then
		histr = histr .. "guisp=" .. opts.sp[2] .. " "

    args.sp = opts.sp[2]
	end

	if opts.attrs then
		histr = histr .. "cterm=" .. table.concat(opts.attrs, ",") .. " "
		histr = histr .. "gui=" .. table.concat(opts.attrs, ",") .. " "

    for _, attr in pairs(opts.attrs) do
      if attr == "NONE" then
        args.bold = false
        args.standout = false
        args.underline = false
        args.undercurl = false
        args.underdotted = false
        args.underdashed = false
        args.strikethrough = false
        args.italic = false
        args.reverse = false
        args.nocombine = false
        break
      end

      args[attr] = true
    end
	end

	if opts.link then
		histr = "highlight! link " .. opts.name .. " " .. opts.link

    args = { link = opts.link }
	end

	if opts.clear then
		histr = "highlight! clear " .. opts.name
    args = {}
	end

  vim.api.nvim_set_hl(0, opts.name, args)
	--vim.cmd(histr)
end

local config = {
    termtrans = false
}

local colors = {
    base03      = { 8,    "#002b36" },
    base02      = { 0,    "#073642" },
    base01      = { 10,   "#586e75" },
    base00      = { 11,   "#657b83" },
    base0       = { 12,   "#839496" },
    base1       = { 14,   "#93a1a1" },
    base2       = { 7,    "#eee8d5" },
    base3       = { 15,   "#fdf6e3" },
    yellow      = { 3,    "#b58900" },
    orange      = { 9,    "#cb4b16" },
    red         = { 1,    "#dc322f" },
    magenta     = { 5,    "#d33682" },
    violet      = { 13,   "#6c71c4" },
    blue        = { 4,    "#268bd2" },
    cyan        = { 6,    "#2aa198" },
    green       = { 2,    "#859900" },
    none        = { "NONE", "NONE"    },
    back        = { 8,    "#002b36" },
}

colors.background = colors.base03
colors.backgroundHighlight = colors.base02
colors.normal = colors.base0
colors.emphasized = colors.base1
colors.comments = colors.base01
colors.secondary = colors.base01

if config.termtrans then
	colors.back = colors.none
end

local attrs = {
    none        = "NONE",
    bold        = "bold",
    underline   = "underline",
    curly       = "undercurl",
    double      = "underdouble",
    dotted      = "underdotted",
    dashed      = "underdashed",
    strike      = "strikethrough",
    reverse     = "reverse",
    inverse     = "reverse",
    italic      = "italic",
    nocombine   = "nocombine",
}

vim.cmd [[
    highlight clear
    if exists("syntax_on")
      syntax reset
    endif
]]

vim.g.colors_name = "bsolarized2"

-- ----------------------------------------------------------------------
-- Builtin groups
-- ----------------------------------------------------------------------

-- ColorColumn	used for the columns set with 'colorcolumn'
highlight {name="ColorColumn", bg=colors.base02}

-- Conceal		placeholder characters substituted for concealed text (see
-- 'conceallevel')
highlight {name="Conceal", fg=colors.blue}

-- Cursor		character under the cursor
highlight {name="Cursor", fg=colors.base03, bg=colors.base01}

-- lCursor		the character under the cursor when |language-mapping| is
-- used (see 'guicursor')
highlight {name="lcursor", link="Cursor"}

-- CursorIM	like Cursor, but used when in IME mode |CursorIM|
highlight {name="CursorIM", link="Cursor"}

-- CursorColumn	Screen-column at the cursor, when 'cursorcolumn' is set.
highlight {name="CursorColumn", bg=colors.base02}

-- CursorLine	Screen-line at the cursor, when 'cursorline' is set.
-- Low-priority if foreground (ctermfg OR guifg) is not set.
highlight {name="CursorLine", bg=colors.base02, attrs={attrs.none}}

-- Directory	directory names (and other special names in listings)
highlight {name="Directory", fg=colors.blue}

-- DiffAdd		diff mode: Added line |diff.txt|
-- DiffChange	diff mode: Changed line |diff.txt|
-- DiffDelete	diff mode: Deleted line |diff.txt|
-- DiffText	diff mode: Changed text within a changed line |diff.txt|
highlight {name="DiffAdd", fg=colors.green, bg=colors.base02, attrs={attrs.bold}}
highlight {name="DiffChange", fg=colors.yellow, bg=colors.base02, attrs={attrs.bold}}
highlight {name="DiffDelete", fg=colors.red, bg=colors.base02, attrs={attrs.bold}}
highlight {name="DiffText", fg=colors.blue, bg=colors.base02, attrs={attrs.bold}}
highlight {name="DiffAdded", link="DiffAdd"}
highlight {name="DiffRemoved", link="DiffDelete"}
highlight {name="DiffFile", fg=colors.blue}
highlight {name="DiffNewFile", fg=colors.red}
highlight {name="DiffLine", fg=colors.blue}

-- EndOfBuffer	filler lines (~) after the end of the buffer. By default,
-- this is highlighted like |hl-NonText|.
--KEEP DEFAULT

-- TermCursor	cursor in a focused terminal
--KEEP DEFAULT

-- TermCursorNC	cursor in an unfocused terminal
--KEEP DEFAULT

-- ErrorMsg	error messages on the command line
highlight {name="ErrorMsg", link="Error"}

-- WinSeparator	separators between window splits
highlight {name="WinSeparator", link="Normal"}
highlight {name="VertSplit", link="WinSeparator"}

-- Folded		line used for closed folds
highlight {name="Folded", fg=colors.base0, bg=colors.base02, sp=colors.base03, attrs={attrs.underline, attrs.bold}}

-- FoldColumn	'foldcolumn'
highlight {name="FoldColumn", fg=colors.base0, bg=colors.base02}

-- SignColumn	column where |signs| are displayed
highlight {name="SignColumn", link="LineNr"}

-- IncSearch	'incsearch' highlighting; also used for the text replaced
-- with ":s///c"
highlight {name="IncSearch", fg=colors.yellow}

-- Substitute	|:substitute| replacement text highlighting
highlight {name="Substitute", fg=colors.yellow}

-- LineNr		Line number for ":number" and ":#" commands, and when 'number' or 'relativenumber' option is set.
highlight {name="LineNr", fg=colors.base01, bg=colors.base02, attrs={attrs.none}}

-- LineNrAbove	Line number for when the 'relativenumber' option is set,
-- above the cursor line.
--KEEP DEFAULT

-- LineNrBelow	Line number for when the 'relativenumber' option is set,
-- below the cursor line.
--KEEP DEFAULT

-- CursorLineNr	Like LineNr when 'cursorline' is set and 'cursorlineopt'
-- contains "number" or is "both", for the cursor line.
highlight {name="CursorLineNr", fg=colors.base0, bg=colors.back, attrs={attrs.bold}}

-- MatchParen	The character under the cursor or just before it, if it is
-- a paired bracket, and its match. |pi_paren.txt|
highlight {name="MatchParen", bg=colors.base00, attrs={attrs.bold}}

-- ModeMsg		'showmode' message (e.g., "-- INSERT --")
highlight {name="ModeMsg", fg=colors.blue}

-- MsgArea		Area for messages and cmdline
--KEEP DEFAULT

-- MsgSeparator	Separator for scrolled messages, `msgsep` flag of 'display'
--KEEP DEFAULT

-- MoreMsg		|more-prompt|
highlight {name="MoreMsg", fg=colors.blue}

-- NonText		'@' at the end of the window, characters from 'showbreak'
-- and other characters that do not really exist in the text (e.g., ">"
-- displayed when a double-wide character doesn't fit at the end of the
-- line). See also |hl-EndOfBuffer|.
highlight {name="NonText", fg=colors.base01, attrs={attrs.none}}

-- Normal		normal text
highlight {name="Normal", fg=colors.base0, bg=colors.black, attr={attrs.none}}

-- NormalFloat	Normal text in floating windows.
highlight {name="NormalFloat", link="Normal"}

-- NormalNC	normal text in non-current windows
--KEEP DEFAULT : cleared

-- Pmenu		Popup menu: normal item.
highlight {name="Pmenu", fg=colors.base0, bg=colors.base02, attrs={attrs.reverse}}

-- PmenuSel	Popup menu: selected item.
highlight {name="PmenuSel", fg=colors.base01, bg=colors.base2, attrs={attrs.reverse}}

-- PmenuSbar	Popup menu: scrollbar.
highlight {name="PmenuSbar", fg=colors.base2, bg=colors.base0, attrs={attrs.reverse}}

-- PmenuThumb	Popup menu: Thumb of the scrollbar.
highlight {name="PmenuThumb", fg=colors.base0, bg=colors.base03, attrs={attrs.reverse}}

-- Question	|hit-enter| prompt and yes/no questions
highlight {name="Question", fg=colors.cyan, bg=colors.none, attrs={attrs.bold}}

-- QuickFixLine	Current |quickfix| item in the quickfix window. Combined
-- with |hl-CursorLine| when the cursor is there.
highlight {name="QuickFixLine", bg=colors.base02}

-- Search		Last search pattern highlighting (see 'hlsearch'). Also
-- used for similar items that need to stand out.
highlight {name="Search", bg=colors.yellow, fg=colors.base3}

-- SpecialKey	Unprintable characters: text displayed differently from
-- what it really is. But not 'listchars' whitespace. |hl-Whitespace|
highlight {name="SpecialKey", fg=colors.base00, bg=colors.base02, attrs={attrs.bold}}

-- SpellBad	Word that is not recognized by the spellchecker. |spell|
-- Combined with the highlighting used otherwise.
-- SpellCap	Word that should start with a capital. |spell| Combined with
-- the highlighting used otherwise.
-- SpellLocal	Word that is recognized by the spellchecker as one that is
-- used in another region. |spell| Combined with the highlighting used
-- otherwise.
-- SpellRare	Word that is recognized by the spellchecker as one that is
-- hardly ever used. |spell| Combined with the highlighting used otherwise.
highlight {name="SpellBad", bg=colors.none, attrs={attrs.curly}, sp=colors.red}
highlight {name="SpellCap", bg=colors.none, attrs={attrs.curly}, sp=colors.violet}
highlight {name="SpellRare", bg=colors.none, attrs={attrs.curly}, sp=colors.cyan}
highlight {name="SpellLocal", bg=colors.none, attrs={attrs.curly}, sp=colors.yellow}

-- StatusLine	status line of current window
-- StatusLineNC	status lines of not-current windows Note: if this is equal
-- to "StatusLine" Vim will use "^^^" in the status line of the current
-- window.
highlight {name="StatusLine", fg=colors.base1, bg=colors.base02, attrs={attrs.reverse}}
highlight {name="StatusLineNC", fg=colors.base00, bg=colors.base02, attrs={attrs.reverse}}

-- TabLine		tab pages line, not active tab page label
-- TabLineFill	tab pages line, where there are no labels
-- TabLineSel	tab pages line, active tab page label
highlight {name="TabLine", fg=colors.base0, bg=colors.base02, attrs={attrs.underline}, sp=colors.base0}
highlight {name="TabLineFill", fg=colors.base0, bg=colors.base02, attrs={attrs.underline}, sp=colors.base0}
highlight {name="TabLineSel", fg=colors.base01, bg=colors.base2, attrs={attrs.underline, attrs.reverse}, sp=colors.base0}

-- Title		titles for output from ":set all", ":autocmd" etc.
highlight {name="Title", fg=colors.blue, attrs={attrs.bold}}

-- Visual		Visual mode selection
-- VisualNOS	Visual mode selection when vim is "Not Owning the
-- Selection".
highlight {name="Visual", fg=colors.base01, bg=colors.base03, attrs={attrs.reverse}}
highlight {name="VisualNOS", fg=colors.none, bg=colors.base03, attrs={attrs.reverse, attrs.standout}}

-- WarningMsg	warning messages
highlight {name="WarningMsg", fg=colors.orange, bg=colors.none, attrs={attrs.bold}}

-- Whitespace	"nbsp", "space", "tab" and "trail" in 'listchars'
-- KEEP DEFAULT : links to NonText

-- WildMenu	current match in 'wildmenu' completion
highlight {name="WildMenu", fg=colors.base2, bg=colors.base02, attrs={attrs.reverse}}

highlight {name="Bold", attrs={attrs.bold}}
highlight {name="Italic", attrs={attrs.italic}}

-- ----------------------------------------------------------------------
-- Syntax groups
-- ----------------------------------------------------------------------

-- *Comment	any comment
highlight {name="Comment", fg=colors.base01, attrs={attrs.italic}}

-- *Constant	any constant
--  String		a string constant: "this is a string"
--  Character	a character constant: 'c', '\n'
--  Number		a number constant: 234, 0xff
--  Boolean	a boolean constant: TRUE, false
--  Float		a floating point constant: 2.3e10
highlight {name="Constant", fg=colors.orange}
highlight {name="String", fg=colors.cyan}
highlight {name="Character", link="String"}
highlight {name="Number", fg=colors.cyan}
highlight {name="Boolean", fg=colors.cyan}
highlight {name="Float", fg=colors.cyan}

-- *Identifier	any variable name
--  Function	function name (also: methods for classes)
highlight {name="Identifier", fg=colors.blue}
highlight {name="Function", fg=colors.blue}

-- *Statement	any statement
--  Conditional	if, then, else, endif, switch, etc.
--  Repeat		for, do, while, etc.
--  Label		case, default, etc.
--  Operator	"sizeof", "+", "*", etc.
--  Keyword	any other keyword
--  Exception	try, catch, throw
highlight {name="Statement", fg=colors.green}
highlight {name="Operator", fg=colors.base1}

-- *PreProc	generic Preprocessor
--  Include	preprocessor #include
--  Define		preprocessor #define
--  Macro		same as Define
--  PreCondit	preprocessor #if, #else, #endif, etc.
highlight {name="PreProc", fg=colors.red}

-- *Type		int, long, char, etc.
--  StorageClass	static, register, volatile, etc.
--  Structure	struct, union, enum, etc.
--  Typedef	A typedef
highlight {name="Type", fg=colors.yellow}

-- *Special	any special symbol
--  SpecialChar	special character in a constant
--  Tag		you can use CTRL-] on this
--  Delimiter	character that needs attention
--  SpecialComment	special things inside a comment
--  Debug		debugging statements
highlight {name="Special", fg=colors.base1}
highlight {name="Delimiter", fg=colors.base1}

-- *Underlined	text that stands out, HTML links
highlight {name="Underlined", fg=colors.violet, attrs={attrs.underline}}

-- *Ignore		left blank, hidden  |hl-Ignore|
highlight {name="Ignore", fg=colors.none, bg=colors.none, attrs={attrs.none}}

-- *Error		any erroneous construct
highlight {name="Error", fg=colors.base03, bg=colors.red,  attrs={attrs.bold}}

-- *Todo		anything that needs extra attention; mostly the keywords
-- TODO FIXME and XXX
highlight {name="Todo", fg=colors.magenta, bg=colors.none, attrs={attrs.bold}}


highlight {name="Added", link="DiffAdd"}
highlight {name="Changed", link="DiffChange"}
highlight {name="Removed", link="DiffDelete"}


-- ----------------------------------------------------------------------
-- Diagnostics
-- ----------------------------------------------------------------------

highlight {name="DiagnosticHint", fg=colors.cyan}
highlight {name="DiagnosticInfo", fg=colors.blue}
highlight {name="DiagnosticWarn", fg=colors.yellow}
highlight {name="DiagnosticError", fg=colors.red}
highlight {name="DiagnosticOk", fg=colors.green}

highlight {name="DiagnosticUnderlineHint", sp=colors.cyan, attrs={attrs.underline}}
highlight {name="DiagnosticUnderlineInfo", sp=colors.blue, attrs={attrs.underline}}
highlight {name="DiagnosticUnderlineWarn", sp=colors.yellow, attrs={attrs.underline}}
highlight {name="DiagnosticUnderlineError", sp=colors.red, attrs={attrs.underline}}
highlight {name="DiagnosticUnderlineOk", sp=colors.green, attrs={attrs.underline}}

highlight {name="DiagnosticDeprecated", fg=colors.base01, attrs={attrs.strike}}
highlight {name="DiagnosticUnnecessary", fg=colors.base01}

-- ----------------------------------------------------------------------
-- Treesitter
-- ----------------------------------------------------------------------

highlight {name="@variable", link="Normal"}
highlight {name="@variable.builtin", link="Keyword"}
highlight {name="@variable.parameter", fg=colors.magenta}
highlight {name="@variable.parameter.builtin", link="@variable.parameter"}
highlight {name="@variable.member", fg=colors.base1}

highlight {name="@constant", link="Constant"}
highlight {name="@constant.builtin", link="Keyword"}
highlight {name="@constant.macro", link="@constant"}

highlight {name="@module", link="Normal"}
highlight {name="@module.builtin", link="Keyword"}
highlight {name="@label", link="Statement"}

highlight {name="@string", link="String"}
highlight {name="@string.regexp", link="Special"}
highlight {name="@string.escape", link="Special"}
highlight {name="@string.special", link="Special"}
highlight {name="@string.special.symbol", link="@string.special"}
highlight {name="@string.special.path", link="@string.special"}
highlight {name="@string.special.url", link="Underlined"}

highlight {name="@character", link="Character"}
highlight {name="@character.special", link="Special"}

highlight {name="@boolean", link="Boolean"}
highlight {name="@number", link="Number"}
highlight {name="@number.float", link="Float"}

highlight {name="@type", link="Type"}
highlight {name="@type.builtin", link="Keyword"}
highlight {name="@type.definition", fg=colors.yellow}
highlight {name="@type.modifier", link="Keyword"}

highlight {name="@attribute", link="Identifier"}
highlight {name="@attribute.builtin", link="Keyword"}
highlight {name="@property", link="Identifier"}

highlight {name="@function", fg=colors.blue}
highlight {name="@function.builtin", link="Keyword"}
highlight {name="@function.macro", link="PreProc"}
highlight {name="@function.call", link="Function"}

highlight {name="@function.method", link="@function"}
highlight {name="@function.method.call", link="@function.call"}

highlight {name="@constructor", link="@function"}
highlight {name="@operator", link="Operator"}

highlight {name="@keyword", link="Keyword"}
highlight {name="@keyword.coroutine", link="@keyword"}
highlight {name="@keyword.function", link="@keyword"}
highlight {name="@keyword.operator", link="@keyword"}
highlight {name="@keyword.import", link="@keyword"}
highlight {name="@keyword.type", link="@keyword"}
highlight {name="@keyword.modifier", link="@keyword"}
highlight {name="@keyword.repeat", link="Statement"}
highlight {name="@keyword.return", link="Statement"}
highlight {name="@keyword.debug", link="@keyword"}
highlight {name="@keyword.exception", link="@keyword"}
highlight {name="@keyword.conditional", link="Statement"}
highlight {name="@keyword.conditional.ternary", link="Statement"}

highlight {name="@keyword.directive", link="PreProc"}
highlight {name="@keyword.directive.value", link="@keyword.directive"}

highlight {name="@punctuation.delimiter", link="Delimiter"}
highlight {name="@punctuation.bracket", link="Delimiter"}
highlight {name="@punctuation.special", link="Delimiter"}

highlight {name="@comment", link="Comment"}
highlight {name="@comment.documentation", link="Comment"}

highlight {name="@comment.error", link="DiagnosticError"}
highlight {name="@comment.warning", link="DiagnosticWarn"}
highlight {name="@comment.note", link="DiagnosticInfo"}
highlight {name="@comment.todo", link="Todo"}

highlight {name="@markup.strong", link="Bold"}
highlight {name="@markup.italic", link="Italic"}
highlight {name="@markup.strikethrough", attrs={attrs.strike}}
highlight {name="@markup.underline", attrs={attrs.underline}}

highlight {name="@markup.heading", link="Heading"}
highlight {name="@markup.heading.1", link="Heading"}
highlight {name="@markup.heading.2", link="Heading"}
highlight {name="@markup.heading.3", link="Heading"}
highlight {name="@markup.heading.4", link="Heading"}
highlight {name="@markup.heading.5", link="Heading"}
highlight {name="@markup.heading.6", link="Heading"}

highlight {name="@markup.quote", fg=colors.cyan}
highlight {name="@markup.math", fg=colors.red}

highlight {name="@markup.link", link="Underlined"}
highlight {name="@markup.link.url", link="Underlined"}
highlight {name="@markup.link.label", link="Underlined"}

highlight {name="@markup.raw", link="Special"}
highlight {name="@markup.raw.block", link="Special"}

highlight {name="@markup.list", fg=colors.blue}
highlight {name="@markup.list.checked", link="@markup.list"}
highlight {name="@markup.list.unchecked", link="@markup.list"}

highlight {name="@diff.plus", link="DiffAdd"}
highlight {name="@diff.minus", link="DiffDelete"}
highlight {name="@diff.delta", link="DiffChange"}

highlight {name="@tag", link="Identifier"}
highlight {name="@tag.builtin", link="@tag"}
highlight {name="@tag.attribute", link="Special"}
highlight {name="@tag.delimiter", link="Delimiter"}

-- ----------------------------------------------------------------------
-- LSP semantic tokens
-- ----------------------------------------------------------------------

highlight {name="@lsp.type.class", link="@type"}
highlight {name="@lsp.type.comment", link="@comment"}
highlight {name="@lsp.type.decorator", link="@attribute"}
highlight {name="@lsp.type.enum", link="@type"}
highlight {name="@lsp.type.enumMember", link="@constant"}
highlight {name="@lsp.type.event", link="@type"}
highlight {name="@lsp.type.function", link="@function"}
highlight {name="@lsp.type.interface", link="@type"}
highlight {name="@lsp.type.keyword", link="@keyword"}
highlight {name="@lsp.type.macro", link="@function.macro"}
highlight {name="@lsp.type.method", link="@function.method"}
highlight {name="@lsp.type.modifier", link="@type.modifier"}
highlight {name="@lsp.type.namespace", link="@module"}
highlight {name="@lsp.type.number", link="@number"}
highlight {name="@lsp.type.operator", link="@operator"}
highlight {name="@lsp.type.parameter", link="@variable.parameter"}
highlight {name="@lsp.type.property", link="@property"}
highlight {name="@lsp.type.regexp", link="@string.regexp"}
highlight {name="@lsp.type.string", link="@string"}
highlight {name="@lsp.type.struct", link="@type"}
highlight {name="@lsp.type.type", link="@type"}
highlight {name="@lsp.type.typeParameter", link="@variable.parameter"}
highlight {name="@lsp.type.variable", link="@variable"}

--highlight {name = "@lsp.mod.abstract", link="Constant"}
--highlight {name = "@lsp.mod.async", link="Constant"}
highlight {name = "@lsp.mod.declaration", attrs={attrs.bold}}
--highlight {name = "@lsp.mod.defaultLibrary", link="Constant"}
highlight {name = "@lsp.mod.definition", attrs={attrs.bold}}
highlight {name = "@lsp.mod.deprecated", attrs={attrs.strike}}
highlight {name = "@lsp.mod.documentation", attris={attrs.italic}}
highlight {name = "@lsp.mod.readonly", link="Constant"}
--highlight {name = "@lsp.mod.static", attrs={attrs.bold} }

-- ----------------------------------------------------------------------
-- NeoTree syntax
-- ----------------------------------------------------------------------

highlight {name="NeoTreeIndentMarker", fg=colors.secondary}
highlight {name="NeoTreeFilename", fg=colors.normal}
highlight {name="NeoTreeExpander", link="NeoTreeIndentMarker"}

highlight {name="NeoTreeDiagTotalCount", fg=colors.normal, attrs={attrs.bold}}

-- ----------------------------------------------------------------------
-- Goc
-- ----------------------------------------------------------------------

highlight {name="GocNormal", link="Comment"}
highlight {name="GocCovered", fg=colors.green, attrs={attrs.bold}}
highlight {name="GocUncovered", fg=colors.red, attrs={attrs.bold}}

-- ----------------------------------------------------------------------
-- Indent Blank Line
-- ----------------------------------------------------------------------

highlight { name="IblIndent", fg=colors.backgroundHighlight }
highlight { name="IblWhitespace", fg=colors.backgroundHighlight }
highlight { name="IblScope", fg=colors.base01, attrs={attrs.bold} }

